@@ -9,22 +9,24 @@ import enum
 
 API = get_api("login")
 
+
 class QrCodeLoginEvents(enum.Enum):
     """
     二维码登录状态枚举
 
     + SCAN: 未扫描二维码
     + CONF: 未确认登录
-    + DONE: 成功
-"""
+    + DONE: 成功"""
+
     SCAN = "scan"
     CONF = "confirm"
     DONE = "done"
 
+
 def get_qrcode():
     """
     获取二维码及登录密钥（后面有用）
-    
+
     Returns:
         tuple[dir, string]: 第一项是二维码图片地址（本地缓存）和登录密钥。登录密钥需要保存。
     """
@@ -32,6 +34,7 @@ def get_qrcode():
     login_key = login.login_key
     return (img, login_key)
 
+
 def check_qrcode_events(login_key):
     """
     检查登录状态。（建议频率 1s，这个 API 也有风控！）
@@ -73,6 +76,7 @@ def check_qrcode_events(login_key):
         c = Credential(sessdata, bili_jct, dedeuserid=dede)
         return [QrCodeLoginEvents.DONE, c]
 
+
 def start_geetest_server():
     """
     开启极验验证服务
@@ -90,12 +94,14 @@ def start_geetest_server():
     """
     return login.start_server()
 
+
 def close_geetest_server():
     """
     关闭极验验证服务（打开极验验证服务后务必关闭掉它，否则会卡住）
     """
     return login.close_server()
 
+
 def done_geetest():
     result = login.get_result()
     if result != -1:
@@ -103,4 +109,5 @@ def done_geetest():
     else:
         return False
 
+
 countries_list = login.get_countries_list()
