@@ -5,6 +5,7 @@ bilibili_api.utils.short
 from .network_httpx import get_session
 from .. import settings
 
+
 async def get_real_url(short_url: str):
     """
     获取短链接跳转目标，以进行操作。
@@ -16,22 +17,23 @@ async def get_real_url(short_url: str):
     try:
         url = short_url
         headers = await get_headers(url)
-        while 'location' in headers.keys():
-            url = headers['location']
+        while "location" in headers.keys():
+            url = headers["location"]
             headers = await get_headers(url)
-        return url # 已经是最终路径
+        return url  # 已经是最终路径
     except Exception as e:
         raise e
 
+
 async def get_headers(short_url):
     """
     获取链接的 headers
     """
     config = {}
-    config['method'] = "GET"
-    config['url'] = short_url
-    config['follow_redirects'] = False
+    config["method"] = "GET"
+    config["url"] = short_url
+    config["follow_redirects"] = False
     if settings.proxy:
-        config['proxies'] = {settings.proxy_use: settings.proxy}
+        config["proxies"] = {settings.proxy_use: settings.proxy}
     resp = await get_session().request("GET", url=short_url, follow_redirects=False)
     return resp.headers
